#ifndef ExRootTreeReader_h
#define ExRootTreeReader_h

/** \class ExRootTreeReader
 *
 *  Class simplifying access to ROOT tree branches
 *
 *  $Date: 2009-02-16 12:17:46 $
 *  $Revision: 1.3 $
 *
 *
 *  \author S. Ovyn - UCL, Louvain-la-Neuve
 *
 */

#include "TROOT.h"
#include "TTree.h"
#include "TString.h"

#include <map>

class ExRootTreeReader
{
public :

  ExRootTreeReader(TTree *tree);
  ~ExRootTreeReader();

  Long64_t GetEntries() const { return fChain ? static_cast<Long64_t>(fChain->GetEntries()) : 0; }
  Bool_t ReadEntry(Long64_t entry);

  TClonesArray *UseBranch(const TString &branchName);

private:

  void Init();
  void Notify();

  TTree *fChain;  // pointer to the analyzed TTree or TChain
  Int_t fCurrentTree; // current Tree number in a TChain

  Bool_t fIsInitDone;

  typedef std::map<TString, std::pair<TBranch*, TClonesArray*> > TBranchMap;

  TBranchMap fBranchMap;
};

#endif // ExRootTreeReader_h
